/**
 * Copyright 2022 Google LLC
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      https://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.google.cast.sample.casthelloaudioandroid;

import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.util.Log;

import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;
import java.util.concurrent.Executor;

public class BitmapImageProvider {

    private URL imageUrl;
    private final String LOG_TAG = "BitmapImageProvider";
    private Executor executor;
    private Bitmap img = null;

    public BitmapImageProvider(String url) {
        try {
            this.imageUrl = new URL(url);
        }catch (MalformedURLException e){
            e.printStackTrace();
        }
    }

    public Bitmap fetchBitmap() {
        try {
            URLConnection conn = imageUrl.openConnection();
            conn.connect();
            InputStream inputStream = conn.getInputStream();
            BufferedInputStream bufferedInputStream = new BufferedInputStream(inputStream);
            img = BitmapFactory.decodeStream(bufferedInputStream);
            bufferedInputStream.close();
            inputStream.close();
        }catch (IOException ioe){
            Log.e(LOG_TAG, "fetchBitmap IOException: "+ioe.getMessage());
            ioe.printStackTrace();
        }

        return img;
    }
}
